@@ -8,14 +8,26 @@ from sqlalchemy.dialects.mysql import BINARY
 from sqlalchemy.types import TypeDecorator
 
 
+class SessionBuilder:
+    _session = None
+
+    @classmethod
+    def build(cls, dsn: str):
+        if not cls._session:
+            db_engine = create_engine(dsn)
+            Session = sessionmaker(bind=db_engine)
+
+            cls._session = Session()
+
+        return cls._session
+
+
 class Repository(BaseRepository):
 
     def __init__(self, aggregate: AggregateRoot, dsn: str):
         super().__init__(aggregate)
-        some_engine = create_engine(dsn)
-        Session = sessionmaker(bind=some_engine)
 
-        self.__session = Session()
+        self.__session = SessionBuilder.build(dsn)
 
     def add(self, aggregate: AggregateRoot) -> None:
         self.__session.add(aggregate)
